# circum-kinect

![build](https://travis-ci.com/LumineerLabs/circum-kinect.svg?branch=master) ![PyPI](https://img.shields.io/pypi/v/circum-kinect)

Kinect sensor plugin for [circum](https://github.com/LumineerLabs/circum).

## Install

```bash
pip3 install circum-kinect
```

## Usage

```bash
```